ABTConfig class

ABT配置

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ABTConfig({List<String>? services, required String abtUrl})
ABTConfig.fromJson(Map<String, dynamic> json)
factory

Properties

abtUrl String
ABT 地址
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
services List<String>?
登录账号
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited