ConversationsRemovedEvent class
会话从分组移除回调事件
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
ConversationsRemovedEvent({required String groupId, required List<
String> conversationIds}) -
ConversationsRemovedEvent.fromJson(Map<
String, dynamic> map) -
factory
Properties
-
conversationIds
↔ List<
String> -
会话列表
getter/setter pair
- groupId ↔ String
-
分组ID
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited