NIMCollectionOption class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

NIMCollectionOption({int? beginTime, int? endTime, NIMQueryDirection? direction, NIMCollection? anchorCollection, int? limit, int? collectionType})
NIMCollectionOption.fromJson(Map<String, dynamic> map)
factory

Properties

anchorCollection NIMCollection?
查询锚点 如果anchor为空, 则以beginTime,endTime为准 如果anchor不为空如果direction为DESC, endTime不为0, 则必须等于anchor的时间, 否则报错 endTime为0, 则以anchor为准 如果dirction为ASC beginTime不为0, 则必须等于anchor的时间, 否则报错 beginTime为0, 则以anhor为准 查询内部不包括anchor
getter/setter pair
beginTime int?
查询开始时间区间,闭区间
getter/setter pair
collectionType int?
收藏类型,为0表示查询所有类型
getter/setter pair
direction NIMQueryDirection?
查询方向,默认按时间从大到小查询
getter/setter pair
endTime int?
查询结束时间区间,闭区间 endTime大于beginTime
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
limit int?
每次查询收藏条数,不超过200
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited