NIMFriendAddApplicationResult class

查询申请添加好友相关信息列表返回结构

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

NIMFriendAddApplicationResult({List<NIMFriendAddApplication>? infos, required int offset, bool? finished})
NIMFriendAddApplicationResult.fromJson(Map<String, dynamic> map)
factory

Properties

finished bool?
分页结束
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
infos List<NIMFriendAddApplication>?
查询返回的列表
getter/setter pair
offset int
下一次的偏移量
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited