NIMTeamMemberQueryOption class

群组成员查询参数

Annotations
  • @JsonSerializable.new()

Constructors

NIMTeamMemberQueryOption({required NIMTeamMemberRoleQueryType roleQueryType, bool? onlyChatBanned, NIMQueryDirection? direction, String? nextToken, int limit = 100})
NIMTeamMemberQueryOption.fromJson(Map<String, dynamic> map)
factory

Properties

direction NIMQueryDirection?
查询方向
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
limit int
分页拉取数量,不建议超过100,默认100
getter/setter pair
nextToken String?
分页偏移,首次传"",后续拉取采用上一次返回的nextToken
getter/setter pair
onlyChatBanned bool?
是否只返回聊天禁言成员列表,YES true: 只返回聊天禁言成员列表,NO 全部成员列表
getter/setter pair
roleQueryType NIMTeamMemberRoleQueryType
查询成员类型
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited