NIMTeamMessageReadReceiptDetail class

群消息已读回执详情

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

NIMTeamMessageReadReceiptDetail({NIMTeamMessageReadReceipt? readReceipt, List<String>? readAccountList, List<String>? unreadAccountList})
NIMTeamMessageReadReceiptDetail.fromJson(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
readAccountList List<String>?
已读账号列表
getter/setter pair
readReceipt NIMTeamMessageReadReceipt?
群消息已读回执
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unreadAccountList List<String>?
未读账号列表
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited