NIMTextTranslationResult class

文本翻译结果

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

NIMTextTranslationResult({String? translatedText, String? sourceLanguage, String? targetLanguage})
NIMTextTranslationResult.fromJson(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceLanguage String?
实际使用的源语言代码(自动检测时由服务端填充)
final
targetLanguage String?
目标语言代码
final
translatedText String?
翻译后的文本
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited