NIMUpdateLocalMessageParams class

本地消息更新参数类

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

NIMUpdateLocalMessageParams({int? subType, String? text, NIMMessageAttachment? attachment, String? localExtension, NIMMessageSendingState? sendingState})
NIMUpdateLocalMessageParams.fromJson(Map<String, dynamic> map)
factory

Properties

attachment NIMMessageAttachment?
消息附属附件,附件类型需要和原始消息附件类型保持一致
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
localExtension String?
消息本地扩展字段
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendingState NIMMessageSendingState?
消息发送状态 仅支持成功和失败, 其它状态返回参数报错
getter/setter pair
subType int?
消息子类型,需要 >= 0
getter/setter pair
text String?
消息内容
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited