OhosPushService class

鸿蒙第三方推送服务。

Annotations
  • @HawkEntryPoint.new()

Constructors

OhosPushService()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enable(bool enable) Future<NIMResult<void>>
开启/关闭第三方推送服务。
isEnable() Future<NIMResult<bool>>
查询当前是否开启第三方推送服务。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited