TeamServicePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • TeamServicePlatform

Constructors

TeamServicePlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
onReceiveTeamJoinActionInfo StreamController<NIMTeamJoinActionInfo>
入群操作回调
getter/setter pair
onSyncFailed StreamController<NIMResult>
同步失败
getter/setter pair
onSyncFinished StreamController<void>
同步完成
getter/setter pair
onSyncStarted StreamController<void>
同步开始
getter/setter pair
onTeamCreated StreamController<NIMTeam>
群组创建回调
getter/setter pair
onTeamDismissed StreamController<NIMTeam>
群组解散回调 @discussion 仅teamId和teamType字段有效
getter/setter pair
onTeamInfoUpdated StreamController<NIMTeam>
群组信息更新回调
getter/setter pair
onTeamJoined StreamController<NIMTeam>
加入群组回调
getter/setter pair
onTeamLeft StreamController<TeamLeftReuslt>
离开群组回调 @discussion 主动离开群组或被管理员踢出群组
getter/setter pair
onTeamMemberInfoUpdated StreamController<List<NIMTeamMember>>
群组成员信息变更回调
getter/setter pair
onTeamMemberJoined StreamController<List<NIMTeamMember>>
群组成员加入回调
getter/setter pair
onTeamMemberKicked StreamController<TeamMemberKickedResult>
群组成员被踢回调
getter/setter pair
onTeamMemberLeft StreamController<List<NIMTeamMember>>
群组成员退出回调
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String
no setterinherited

Methods

acceptInvitation(NIMTeamJoinActionInfo invitationInfo) Future<NIMResult<NIMTeam>>
同意邀请入群
acceptJoinApplication(NIMTeamJoinActionInfo applicationInfo) Future<NIMResult<void>>
接受入群申请请求
addTeamMembersFollow(String teamId, NIMTeamType teamType, List<String> accountIds) Future<NIMResult<void>>
添加群组成员关注 teamId 群组id,群组 ID 为空报错 191004 参数错误 teamType 群组类型,群组类型不是高级群或超级群,报错 191004 参数错误 accountIds 账号id列表, size==0,返回 191004 参数错误
applyJoinTeam(String teamId, NIMTeamType teamType, String? postscript) Future<NIMResult<NIMTeam>>
申请加入群组
clearAllTeamJoinActionInfo() Future<NIMResult<void>>
清空所有群申请
clearAllTeamJoinActionInfoEx(NIMTeamClearJoinActionInfoOption? option) Future<NIMResult<void>>
清空所有群申请(扩展版),支持按群类型过滤 option 清理条件,为 null 时清理所有申请
createTeam(NIMCreateTeamParams createTeamParams, List<String>? inviteeAccountIds, String? postscript, NIMAntispamConfig? antispamConfig) Future<NIMResult<NIMCreateTeamResult>>
创建群组
deleteTeamJoinActionInfo(NIMTeamJoinActionInfo application) Future<NIMResult<void>>
删除群申请 application需要删除的群申请
dismissTeam(String teamId, NIMTeamType teamType) Future<NIMResult<void>>
解散群组
getJoinedTeamCount(List<NIMTeamType> teamTypes) Future<NIMResult<int>>
获取当前已经加入的群组个数
getJoinedTeamList(List<NIMTeamType> teamTypes) Future<NIMResult<List<NIMTeam>>>
获取当前已经加入的群组列表
getManagerTeamList({List<NIMTeamType>? teamTypes}) Future<NIMResult<List<NIMTeam>>>
获取当前自己管理的群组列表(群主 + 管理员) 返回群组按群组创建时间升序排序 只查本地 teamTypes 群组类型列表,如果为null,或者列表为empty,表示查询所有群类型,否则按输入群类型进行查询
getOwnerTeamList({List<NIMTeamType>? teamTypes}) Future<NIMResult<List<NIMTeam>>>
获取当前自己的群组列表 返回群组按群组创建时间升序排序 需要判断群组是否有效且自己在群中 只查本地 teamTypes 群组类型列表,如果为null,或者列表为empty, 表示查询所有所有群类型,否则按输入群类型进行查询
getTeamInfo(String teamId, NIMTeamType teamType) Future<NIMResult<NIMTeam>>
获取群组信息
getTeamInfoByIds(List<String> teamIds, NIMTeamType teamType) Future<NIMResult<List<NIMTeam>>>
根据群组id获取群组信息
getTeamInfoFromCloud({required String teamId, required NIMTeamType teamType}) Future<NIMResult<NIMTeam>>
从云端查询群组信息 teamId 群组ID teamType 群组类型
getTeamJoinActionInfoList(NIMTeamJoinActionInfoQueryOption queryOption) Future<NIMResult<NIMTeamJoinActionInfoResult>>
获取群加入相关信息
getTeamMemberInvitor(String teamId, NIMTeamType teamType, List<String> accountIds) Future<NIMResult<Map<String, String>>>
根据账号id列表获取群组成员邀请人
getTeamMemberList(String teamId, NIMTeamType teamType, NIMTeamMemberQueryOption queryOption) Future<NIMResult<NIMTeamMemberListResult>>
获取群组成员列表
getTeamMemberListByIds(String teamId, NIMTeamType teamType, List<String> accountIds) Future<NIMResult<List<NIMTeamMember>>>
根据账号id列表获取群组成员列表
handleMethodCall(String method, dynamic arguments) Future
inherited
inviteMember(String teamId, NIMTeamType teamType, List<String> inviteeAccountIds, String? postscript) Future<NIMResult<List<String>>>
邀请成员加入群组
inviteMemberEx(String teamId, NIMTeamType teamType, NIMTeamInviteParams inviteeParams) Future<NIMResult<List<String>>>
邀请成员加入群组 teamId 群组id teamType 群组类型 inviteeParams 被邀请加入群的参数
invokeMethod(String method, {Map<String, dynamic>? arguments}) Future<Map<String, dynamic>>
inherited
kickMember(String teamId, NIMTeamType teamType, List<String>? memberAccountIds) Future<NIMResult<void>>
踢出群组成员
leaveTeam(String teamId, NIMTeamType teamType) Future<NIMResult<void>>
退出群组
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEvent(String method, dynamic arguments) Future
inherited
registerWebAPI() → void
inherited
rejectInvitation(NIMTeamJoinActionInfo invitationInfo, String? postscript) Future<NIMResult<void>>
拒绝邀请入群请求
rejectJoinApplication(NIMTeamJoinActionInfo applicationInfo, String? postscript) Future<NIMResult<void>>
拒绝入群申请
removeTeamMembersFollow(String teamId, NIMTeamType teamType, List<String> accountIds) Future<NIMResult<void>>
移除群组成员关注 teamId 群组id,群组 ID 为空报错 191004 参数错误 teamType 群组类型,群组类型不是高级群或超级群,报错 191004 参数错误 accountIds 账号id列表, size==0,返回 191004 参数错误
searchTeamByKeyword(String keyword) Future<NIMResult<List<NIMTeam>>>
根据关键字搜索群信息
searchTeamMembers(NIMTeamMemberSearchOption searchOption) Future<NIMResult<NIMTeamMemberListResult>>
根据关键字搜索群成员
searchTeamMembersEx(NIMSearchTeamMemberParams searchParams) Future<NIMResult<Map<NIMTeamRefer, List<NIMTeamMember>>>>
本地搜索群成员(扩展,支持跨多个群) searchParams 搜索参数,包含关键词、群引用列表、分页 token 等 返回以 NIMTeamRefer 为 key、匹配成员列表为 value 的 Map
searchTeams(NIMTeamSearchParams searchParams) Future<NIMResult<List<NIMTeam>>>
本地全文搜索群信息 searchParams 搜索参数,包含关键词、群类型、搜索字段等 返回匹配的 NIMTeam 列表
setTeamChatBannedMode(String teamId, NIMTeamType teamType, NIMTeamChatBannedMode chatBannedMode) Future<NIMResult<void>>
设置群组聊天禁言模式
setTeamMemberChatBannedStatus(String teamId, NIMTeamType teamType, String accountId, bool chatBanned) Future<NIMResult<void>>
设置群组成员聊天禁言状态
toString() String
A string representation of this object.
inherited
transferTeamOwner(String teamId, NIMTeamType teamType, String accountId, bool leave) Future<NIMResult<void>>
移交群主
updateSelfTeamMemberInfo(String teamId, NIMTeamType teamType, NIMUpdateSelfMemberInfoParams memberInfoParams) Future<NIMResult<void>>
修改自己的群成员信息
updateTeamInfo(String teamId, NIMTeamType teamType, NIMUpdateTeamInfoParams updateTeamInfoParams, NIMAntispamConfig? antispamConfig) Future<NIMResult<void>>
更新群组
updateTeamMemberNick(String teamId, NIMTeamType teamType, String accountId, String teamNick) Future<NIMResult<void>>
修改群成员昵称
updateTeamMemberRole(String teamId, NIMTeamType teamType, List<String> memberAccountIds, NIMTeamMemberRole memberRole) Future<NIMResult<void>>
设置成员角色

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance TeamServicePlatform
getter/setter pair