V2NIMChatroomQueueLevelMode enum

聊天室队列操作权限

Inheritance
Available extensions

Values

V2NIM_CHATROOM_QUEUE_LEVEL_MODE_ANY → const V2NIMChatroomQueueLevelMode

所有人都有权限操作

V2NIM_CHATROOM_QUEUE_LEVEL_MODE_MANAGER → const V2NIMChatroomQueueLevelMode

只有创建者/管理员才能操作

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<V2NIMChatroomQueueLevelMode>
A constant List of the values in this enum, in order of their declaration.