V2NIMMessageStreamChunk class

流式消息分片信息 该类表示流式消息分片信息,用于流式回复的分片文本数据。

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

V2NIMMessageStreamChunk({String? content, int? messageTime, int? chunkTime, int type = 0, int? index})
V2NIMMessageStreamChunk.fromJson(Map<String, dynamic> map)
factory

Properties

chunkTime int?
流式消息当前分片时间 注意:chunkTime >= msgTime
getter/setter pair
content String?
流式回复分片文本
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
index int?
分片序号,从0开始
getter/setter pair
messageTime int?
流式消息时间,即占位消息时间
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
类型,当前仅支持0表示文本
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited