V2NIMRemoveTopicsParams class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

V2NIMRemoveTopicsParams({List<V2NIMTopic>? topicList})
V2NIMRemoveTopicsParams.fromJson(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topicList List<V2NIMTopic>?
待删除话题列表
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited