onChatroomQueuePolledEvent class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

onChatroomQueuePolledEvent({required int instanceId, V2NIMChatroomQueueElement? element})
onChatroomQueuePolledEvent.fromJson(Map<String, dynamic> json)
factory

Properties

element V2NIMChatroomQueueElement?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
instanceId int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited