NIMCollection class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
Properties
- collectionData ↔ String?
-
收藏数据, 最大 20480 字节
getter/setter pair
- collectionId ↔ String?
-
收藏信息客户端 ID, 收藏时若存在相同客户端 ID 则覆盖
getter/setter pair
- collectionType ↔ int?
-
收藏索引,大于 0, 可以按该字段分类
getter/setter pair
- createTime ↔ int?
-
创建时间
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverExtension ↔ String?
-
收藏信息客户端 ID, 收藏时若存在相同客户端 ID 则覆盖
getter/setter pair
- uniqueId ↔ String?
-
去重唯一ID, 如果ID相同, 则不会新增收藏,只更新之前的收藏内容
getter/setter pair
- updateTime ↔ int?
-
更新时间
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited