NIMExportMessageOption class
消息导出选项 @since v10.9.75
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
NIMExportMessageOption({required String path, int? beginTime, int? endTime, List<
String> ? conversationIds}) -
NIMExportMessageOption.fromJson(Map<
String, dynamic> map) -
factory
Properties
- beginTime ↔ int?
-
导出消息的开始时间(毫秒),为 null 则从最早消息开始
getter/setter pair
-
conversationIds
↔ List<
String> ? -
会话 ID 列表,为 null 或空则导出所有会话消息
getter/setter pair
- endTime ↔ int?
-
导出消息的结束时间(毫秒),为 null 则到最新消息结束
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- path ↔ String
-
导出文件路径,不能为空
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited