NIMFriendClearAddApplicationOption class
清空好友申请的过滤选项(SDK 10.9.76+)
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- NIMFriendClearAddApplicationOption({int? timestamp, NIMFriendAddApplicationType? type})
-
NIMFriendClearAddApplicationOption.fromJson(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp ↔ int?
-
清空该时间戳(ms)之前的申请记录;为 null 时不按时间过滤
getter/setter pair
- type ↔ NIMFriendAddApplicationType?
-
申请类型:收到 / 发出;为 null 时清空全部类型
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited