NIMLastMessage class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- NIMLastMessage({NIMLastMessageState? lastMessageState, NIMMessageRefer? messageRefer, NIMMessageType? messageType, int? subType, NIMMessageSendingState? sendingState, String? text, NIMMessageAttachment? attachment, String? revokeAccountId, NIMMessageRevokeType? revokeType, String? serverExtension, String? callbackExtension, String? senderName})
-
NIMLastMessage.fromJson(Map<
String, dynamic> map) -
factory
Properties
- attachment ↔ NIMMessageAttachment?
-
消息附件,状态为消息时有效
getter/setter pair
- callbackExtension ↔ String?
-
第三方回调扩展字段, 透传字段
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastMessageState ↔ NIMLastMessageState?
-
会话最新一条消息状态
getter/setter pair
- messageRefer ↔ NIMMessageRefer?
-
最后一条消息的引用
getter/setter pair
- messageType ↔ NIMMessageType?
-
消息类型,状态为消息时有效
getter/setter pair
- revokeAccountId ↔ String?
-
消息撤回者账号,状态为撤回时有效
getter/setter pair
- revokeType ↔ NIMMessageRevokeType?
-
消息撤回类型,状态为撤回时有效
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderName ↔ String?
-
消息发送者名称
getter/setter pair
- sendingState ↔ NIMMessageSendingState?
-
消息发送状态,状态为消息时有效
getter/setter pair
- serverExtension ↔ String?
-
消息服务端扩展
getter/setter pair
- subType ↔ int?
-
消息子类型,0:表示没有子类型,状态为消息时有效
getter/setter pair
- text ↔ String?
-
撤回时为撤回附言 消息时消息文本内容
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited