NIMNotificationRouteConfig class
路由抄送相关配置
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- NIMNotificationRouteConfig({bool? routeEnabled, String? routeEnvironment})
-
NIMNotificationRouteConfig.fromJson(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- routeEnabled ↔ bool?
-
是否需要路由通知。(抄送)true:需要。false:不需要
getter/setter pair
- routeEnvironment ↔ String?
-
环境变量,用于指向不同的抄送,第三方回调等配置
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited