V2NIMChatroomMemberQueryOption class
分页查询聊天室成员参数
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
V2NIMChatroomMemberQueryOption({List<
V2NIMChatroomMemberRole> ? memberRoles, bool? onlyBlocked, bool? onlyChatBanned, bool? onlyOnline, String? pageToken, int? limit}) -
V2NIMChatroomMemberQueryOption.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit ↔ int?
-
查询数量
getter/setter pair
-
memberRoles
↔ List<
V2NIMChatroomMemberRole> ? -
需要查询的成员类型,如果列表为空,表示查询所有类型的成员
getter/setter pair
- onlyBlocked ↔ bool?
-
是否只返回黑名单成员
getter/setter pair
- onlyChatBanned ↔ bool?
-
是否只返回禁言用户
getter/setter pair
- onlyOnline ↔ bool?
-
是否只查询在线成员,只针对固定成员生效,其他类型成员只有在线状态
getter/setter pair
- pageToken ↔ String?
-
偏移量 首次传“”,后续查询传前一次返回的pageToken
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited